# API Reference

This page provides documentation for Recursivist's Python API, automatically generated from the source code's docstrings.

## Core Module

::: recursivist.core

## Exports Module

::: recursivist.exports

## Compare Module

::: recursivist.compare

## JSX Export Module

::: recursivist.jsx_export
